<?php
/**
 * Helper functions for the admin: Add inpost screen meta boxes.
 *
 * @package    Genesis Prose Extras
 * @subpackage Admin
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


add_action( 'admin_menu', 'ddw_gpex_add_custom_css_metaboxes' );
/**
 * Add new meta boxes for inpost/ inpage edit screens.
 *
 * @since 1.0.0
 *
 * @uses  get_post_types()
 * @uses  post_type_supports()
 * @uses  add_meta_box()
 *
 * @param $post_type
 * @param $gpex_via
 */
function ddw_gpex_add_custom_css_metaboxes() {

	foreach ( (array) get_post_types( array( 'public' => true ) ) as $post_type ) {

		if ( post_type_supports( $post_type, 'gpex-inpost-css' ) ) {

			$gpex_via = ' <small>(' . sprintf( __( 'via %s', 'genesis-prose-extras' ), __( 'Genesis Prose Extras', 'genesis-prose-extras' ) ) . ')</small>';

			/** Register meta box for inpost screen */
			add_meta_box(
		    	'gpex_inpost_custom_css',
				__( 'Custom CSS', 'genesis-prose-extras' ) . $gpex_via,
				'ddw_gpex_insert_custom_css_textarea',
				$post_type,
				'normal',
				'high'
		    );

			/** Enqueue additional CSS styles plus some JavaScript */
		    add_action( 'admin_enqueue_scripts', 'ddw_gpex_inpost_metaboxes_admin_styles', 10, 1 );

		}  // end-if

	}  // end foreach

}  // end of function ddw_gpex_add_custom_css_metaboxes


/**
 * HTML/ Form for the meta box. //style="width: 100%;"
 *
 * @since  1.0.0
 *
 * @uses   wp_nonce_field()
 * @uses   get_post_type_object()
 * @uses   genesis_get_custom_field()
 *
 * @global $post
 */
function ddw_gpex_insert_custom_css_textarea() {

	global $post;

	/** Set nonce for custom field saving */
	wp_nonce_field( 'gpex_inpost_custom_css_save', 'gpex_inpost_custom_css_nonce' );

	/** Begin form code */
	?>

	    <p>
	      <label for="gpex_inpost_custom_css"><?php echo sprintf( __( 'Add some %s specific CSS rules here', 'genesis-prose-extras' ) . ':', get_post_type_object( $post->post_type )->labels->singular_name ); ?>
	      </label>
	    </p>

		<p>
			<textarea name="gpex_custom_css[_gpex_inpost_custom_css]" id="gpex_inpost_custom_css" cols="4" rows="7"><?php echo esc_textarea( genesis_get_custom_field( '_gpex_inpost_custom_css' ) ); ?></textarea>
		</p>

		<p class="description">
			<?php echo sprintf( __( 'Note: The above styles will only apply to this unique item (title: &raquo;%s&laquo;)!', 'genesis-prose-extras' ), esc_attr( get_the_title() ) ); ?>
		</p>

	<?php
	/** ^End form code */

}  // end of function ddw_gpex_insert_custom_css_textarea


add_action( 'save_post', 'ddw_gpex_save_custom_css_content', 1, 2 );
/**
 * Save the custom CSS content.
 *
 * @since 1.0.0
 *
 * @uses  wp_parse_args()
 * @uses  genesis_save_custom_fields()
 *
 * @param $post_id
 * @param $post
 */
function ddw_gpex_save_custom_css_content( $post_id, $post ) {

	if ( ! isset( $_POST[ 'gpex_custom_css' ] ) ) {
		return;
	}

	/** Merge user submitted options with fallback defaults */
	$data = wp_parse_args( $_POST[ 'gpex_custom_css' ], array(
		'_gpex_inpost_custom_css' => '',
	) );

	/** Save custom field data */
	genesis_save_custom_fields(
		$data,
		'gpex_inpost_custom_css_save',
		'gpex_inpost_custom_css_nonce',
		$post,
		$post_id
	);

}  // end of function ddw_gpex_save_custom_css_content


/**
 * Conditionally enqueue our own helper CSS styles plus some JavaScript.
 *    (Only for post type inpost screens that support our custom CSS!)
 *
 * @since  1.0.0
 *
 * @uses   get_post_types()
 * @uses   post_type_supports()
 * @uses   wp_enqueue_style()
 * @uses   wp_enqueue_script()
 *
 * @param  $hook
 * @param  $post_type
 */
function ddw_gpex_inpost_metaboxes_admin_styles( $hook ) {

	/** Only on general post type edit screens */
	if ( 'post-new.php' == $hook || 'post.php' == $hook ) {

		foreach ( (array) get_post_types( array( 'public' => true ) ) as $post_type ) {

			if ( post_type_supports( $post_type, 'gpex-inpost-css' ) ) {

				/** Enqueue the stylesheet */
				wp_enqueue_style( 'prose-admin-extras' );

				/** Enqueue the script */
				wp_enqueue_script( 'gpex-admin-js' );

		    }  // end-if post type support check

		}  // end foreach

	}  // end-if admin page hook check

}  // end of function ddw_gpex_inpost_metaboxes_admin_styles